htmlgen bug

[email protected] (Simon Andr?s) 13 Dec 2002 19:43:41 +0100
Newsgroups gmane.lisp.open-source.franz
Message-ID <[email protected]>
I get the following with htmlgen in aserve 1.2.24: 

CL-USER(133): (net.html.generator:html-print '(:html (:body (:prin1-safe "foo")))  *standard-output*)
<HTML><BODY>
Error: (:INTERNAL (:TOP-LEVEL-FORM "htmlgen.cl" 15088) 1) got 6 args,
wanted 5 args.
  [condition type: PROGRAM-ERROR]

Restart actions (select using :continue):
 0: Return to Top Level (an "abort" restart).
 1: Abort entirely from this process.
[1] CL-USER(134): 


The same happens with :comment. The following patch fixes both.

--- htmlgen.cl.orig	Sat Aug 10 00:25:54 2002
+++ htmlgen.cl	Fri Dec 13 11:12:50 2002
@@ -533,8 +533,8 @@
	`(progn ,@(mapcar #'(lambda (bod)
			      `(prin1-safe-http ,bod))
			  body)))
-  #'(lambda (ent cmd args form stream)
-      (declare (ignore args ent))
+  #'(lambda (ent cmd args form subst stream)
+      (declare (ignore args ent subst))
       (assert (eql 2 (length form)))
       (if* (eq cmd :full)
	 then (emit-safe stream (format nil "~s" (cadr form)))
@@ -551,8 +551,8 @@
	      (html ,@body)
	      (write-string "-->" *html-stream*)))
   
-  #'(lambda (ent cmd args form stream)
-      (declare (ignore ent cmd args))
+  #'(lambda (ent cmd args form subst stream)
+      (declare (ignore ent cmd args subst))
       (format stream "<!--~a-->" (cadr form))))
 
Andras